==> sunwise_wise_client-0.1.0.tar.gz: sunwise_wise_client-0.1.0/wise_client/models/consumption_tier.py <==
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ConsumptionTier")


@_attrs_define
class ConsumptionTier:
    """
    Attributes:
        tier (str):
        consumption (float):
    """

    tier: str
    consumption: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        tier = self.tier

        consumption = self.consumption

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "tier": tier,
                "consumption": consumption,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        tier = d.pop("tier")

        consumption = d.pop("consumption")

        consumption_tier = cls(
            tier=tier,
            consumption=consumption,
        )

        consumption_tier.additional_properties = d
        return consumption_tier

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> sunwise_wise_client-0.1.2.tar.gz: sunwise_wise_client-0.1.2/wise_client/models/consumption_tier.py <==
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ConsumptionTier")


@_attrs_define
class ConsumptionTier:
    """
    Attributes:
        tier (str):
        consumption (float):
    """

    tier: str
    consumption: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        tier = self.tier

        consumption = self.consumption

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "tier": tier,
                "consumption": consumption,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        tier = d.pop("tier")

        consumption = d.pop("consumption")

        consumption_tier = cls(
            tier=tier,
            consumption=consumption,
        )

        consumption_tier.additional_properties = d
        return consumption_tier

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
